==> jc-1.4.0.tar.gz: scm/scmCatchEntry.h <==
// class scm.scmCatchEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 6f380b0fcc9c5cba scm_scmCatchEntry

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmCatchEntry_H_
#define _JC_scm_scmCatchEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmCatchEntry$sub_refs	_jc_scm_scmCatchEntry$sub_refs;
typedef struct _jc_scm_scmCatchEntry$sub_nonrefs	_jc_scm_scmCatchEntry$sub_nonrefs;
typedef struct _jc_scm_scmCatchEntry$refs	_jc_scm_scmCatchEntry$refs;
typedef struct _jc_scm_scmCatchEntry$nonrefs	_jc_scm_scmCatchEntry$nonrefs;
typedef struct _jc_scm_scmCatchEntry$object	_jc_scm_scmCatchEntry$object;

typedef const struct _jc_scm_scmCatchEntry$vmethods	_jc_scm_scmCatchEntry$vmethods;
typedef const struct _jc_scm_scmCatchEntry$vtable	_jc_scm_scmCatchEntry$vtable;
typedef const struct _jc_scm_scmCatchEntry$vtype	_jc_scm_scmCatchEntry$vtype;

// Constructors
extern void _jc_scm_scmCatchEntry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmCatchEntry$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_scmCatchEntry$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmCatchEntry$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_scmCatchEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmCatchEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_scmCatchEntry$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmCatchEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmCatchEntry$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmCatchEntry$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmCatchEntry$object *);
};

// Vtable
struct _jc_scm_scmCatchEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmCatchEntry$vmethods	scm_scmCatchEntry;
};

// Vtype
struct _jc_scm_scmCatchEntry$vtype {
	_jc_type			type;
	_jc_scm_scmCatchEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmCatchEntry$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmCatchEntry$refs {
    _jc_scm_scmCatchEntry$sub_refs	scm_scmCatchEntry;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmCatchEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmCatchEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmCatchEntry$sub_nonrefs	scm_scmCatchEntry;
};

// Object instance structure
struct _jc_scm_scmCatchEntry$object {
	_jc_scm_scmCatchEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmCatchEntry$vtype	*vtype;
	_jc_scm_scmCatchEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmCatchEntry$vtype _jc_scm_scmCatchEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmCatchEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmCatchEntry$class_object;

#endif	/* _JC_scm_scmCatchEntry_H_ */

==> jc-1.4.6.tar.gz: scm/scmCatchEntry.h <==
// class scm.scmCatchEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 6f380b0fcc9c5cba scm_scmCatchEntry

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmCatchEntry_H_
#define _JC_scm_scmCatchEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmCatchEntry$sub_refs	_jc_scm_scmCatchEntry$sub_refs;
typedef struct _jc_scm_scmCatchEntry$sub_nonrefs	_jc_scm_scmCatchEntry$sub_nonrefs;
typedef struct _jc_scm_scmCatchEntry$refs	_jc_scm_scmCatchEntry$refs;
typedef struct _jc_scm_scmCatchEntry$nonrefs	_jc_scm_scmCatchEntry$nonrefs;
typedef struct _jc_scm_scmCatchEntry$object	_jc_scm_scmCatchEntry$object;

typedef const struct _jc_scm_scmCatchEntry$vmethods	_jc_scm_scmCatchEntry$vmethods;
typedef const struct _jc_scm_scmCatchEntry$vtable	_jc_scm_scmCatchEntry$vtable;
typedef const struct _jc_scm_scmCatchEntry$vtype	_jc_scm_scmCatchEntry$vtype;

// Constructors
extern void _jc_scm_scmCatchEntry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmCatchEntry$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_scmCatchEntry$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmCatchEntry$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_scmCatchEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmCatchEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_scmCatchEntry$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmCatchEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmCatchEntry$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmCatchEntry$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmCatchEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_scmCatchEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmCatchEntry$vmethods	scm_scmCatchEntry;
};

// Vtype
struct _jc_scm_scmCatchEntry$vtype {
	_jc_type			type;
	_jc_scm_scmCatchEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmCatchEntry$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmCatchEntry$refs {
    _jc_scm_scmCatchEntry$sub_refs	scm_scmCatchEntry;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmCatchEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmCatchEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmCatchEntry$sub_nonrefs	scm_scmCatchEntry;
};

// Object instance structure
struct _jc_scm_scmCatchEntry$object {
	_jc_scm_scmCatchEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmCatchEntry$vtype	*vtype;
	_jc_scm_scmCatchEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmCatchEntry$vtype _jc_scm_scmCatchEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmCatchEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmCatchEntry$class_object;

#endif	/* _JC_scm_scmCatchEntry_H_ */
